==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/IntercomponentQueueEntrySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.IntercomponentQueueEntry;
import io.ciera.tool.sql.ooaofooa.instance.IntercomponentQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.StackFrameSet;
import io.ciera.tool.sql.ooaofooa.instance.StackSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.StackFrameSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.StackSetImpl;

import java.util.Arrays;
import java.util.List;


public class IntercomponentQueueEntrySetImpl extends InstanceSet<IntercomponentQueueEntrySet,IntercomponentQueueEntry> implements IntercomponentQueueEntrySet {

    // attributes
    @Override
    public void setStack_ID( UniqueId ref_Stack_ID ) throws XtumlException {
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) intercomponentqueueentry.setStack_ID( ref_Stack_ID );
    }
    @Override
    public void setStack_Frame_ID( UniqueId ref_Stack_Frame_ID ) throws XtumlException {
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) intercomponentqueueentry.setStack_Frame_ID( ref_Stack_Frame_ID );
    }
    @Override
    public void setExecution_Engine_ID( UniqueId ref_Execution_Engine_ID ) throws XtumlException {
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) intercomponentqueueentry.setExecution_Engine_ID( ref_Execution_Engine_ID );
    }


    // selections
    @Override
    public StackFrameSet R2966_has_queued_StackFrame() throws XtumlException {
        StackFrameSet stackframeset = new StackFrameSetImpl();
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) stackframeset.add( intercomponentqueueentry.R2966_has_queued_StackFrame() );
        return stackframeset;
    }
    @Override
    public StackSet R2966_is_enqueued_with_Stack() throws XtumlException {
        StackSet stackset = new StackSetImpl();
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) stackset.add( intercomponentqueueentry.R2966_is_enqueued_with_Stack() );
        return stackset;
    }
    @Override
    public ComponentInstanceSet R2977_enqueued_by_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) componentinstanceset.add( intercomponentqueueentry.R2977_enqueued_by_ComponentInstance() );
        return componentinstanceset;
    }


    @Override
    public IntercomponentQueueEntry nullElement() {
        return IntercomponentQueueEntryImpl.EMPTY_INTERCOMPONENTQUEUEENTRY;
    }

    @Override
    public IntercomponentQueueEntrySet emptySet() {
      return new IntercomponentQueueEntrySetImpl();
    }

    @Override
    public IntercomponentQueueEntrySet value() {
        return this;
    }

    @Override
    public List<IntercomponentQueueEntry> elements() {
        return Arrays.asList(toArray(new IntercomponentQueueEntry[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/IntercomponentQueueEntrySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.IntercomponentQueueEntry;
import io.ciera.tool.sql.ooaofooa.instance.IntercomponentQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.StackFrameSet;
import io.ciera.tool.sql.ooaofooa.instance.StackSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.StackFrameSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.StackSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class IntercomponentQueueEntrySetImpl extends InstanceSet<IntercomponentQueueEntrySet,IntercomponentQueueEntry> implements IntercomponentQueueEntrySet {

    public IntercomponentQueueEntrySetImpl() {
    }

    public IntercomponentQueueEntrySetImpl(Comparator<? super IntercomponentQueueEntry> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setExecution_Engine_ID( UniqueId ref_Execution_Engine_ID ) throws XtumlException {
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) intercomponentqueueentry.setExecution_Engine_ID( ref_Execution_Engine_ID );
    }
    @Override
    public void setStack_ID( UniqueId ref_Stack_ID ) throws XtumlException {
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) intercomponentqueueentry.setStack_ID( ref_Stack_ID );
    }
    @Override
    public void setStack_Frame_ID( UniqueId ref_Stack_Frame_ID ) throws XtumlException {
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) intercomponentqueueentry.setStack_Frame_ID( ref_Stack_Frame_ID );
    }


    // selections
    @Override
    public StackFrameSet R2966_has_queued_StackFrame() throws XtumlException {
        StackFrameSet stackframeset = new StackFrameSetImpl();
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) stackframeset.add( intercomponentqueueentry.R2966_has_queued_StackFrame() );
        return stackframeset;
    }
    @Override
    public StackSet R2966_is_enqueued_with_Stack() throws XtumlException {
        StackSet stackset = new StackSetImpl();
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) stackset.add( intercomponentqueueentry.R2966_is_enqueued_with_Stack() );
        return stackset;
    }
    @Override
    public ComponentInstanceSet R2977_enqueued_by_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( IntercomponentQueueEntry intercomponentqueueentry : this ) componentinstanceset.add( intercomponentqueueentry.R2977_enqueued_by_ComponentInstance() );
        return componentinstanceset;
    }


    @Override
    public IntercomponentQueueEntry nullElement() {
        return IntercomponentQueueEntryImpl.EMPTY_INTERCOMPONENTQUEUEENTRY;
    }

    @Override
    public IntercomponentQueueEntrySet emptySet() {
      return new IntercomponentQueueEntrySetImpl();
    }

    @Override
    public IntercomponentQueueEntrySet emptySet(Comparator<? super IntercomponentQueueEntry> comp) {
      return new IntercomponentQueueEntrySetImpl(comp);
    }

    @Override
    public IntercomponentQueueEntrySet value() {
        return this;
    }

    @Override
    public List<IntercomponentQueueEntry> elements() {
        return Arrays.asList(toArray(new IntercomponentQueueEntry[0]));
    }

}
